@@ -41,7 +41,6 @@
 #include <Lum/TextValue.h>
 #include <Lum/TimeSelect.h>
 
-#include "Configuration.h"
 #include "Trend.h"
 #include "Util.h"
 
@@ -179,59 +178,60 @@ public:
   }
 };
 
-class EntriesEntry : public Lum::Model::ListTable::Entry
+class EntryDataProvider : public EntryModel::DataProvider
 {
 public:
-  ::Entry *entry;
-
-public:
-  EntriesEntry(Lum::Model::ListTable *table, ::Entry* entry)
-  : Lum::Model::ListTable::Entry(table),
-    entry(entry)
-  {
-    // no code
-  }
-
-  std::wstring GetString(size_t column) const
+  std::wstring GetString(const EntryModel::Iterator& iter, size_t column) const
   {
     if (column==1) {
       std::wstring res;
 
-      res=Lum::Base::NumberToWString(entry->time.GetHour());
+      res=Lum::Base::NumberToWString((*iter)->time.GetHour());
       res.append(L":");
-      if (entry->time.GetMinute()<10) {
+      if ((*iter)->time.GetMinute()<10) {
         res.append(L"0");
       }
       else {
-        res.append(Lum::Base::NumberToWString(entry->time.GetMinute()/10));
+        res.append(Lum::Base::NumberToWString((*iter)->time.GetMinute()/10));
       }
-      res.append(Lum::Base::NumberToWString(entry->time.GetMinute()%10));
+      res.append(Lum::Base::NumberToWString((*iter)->time.GetMinute()%10));
 
       return res;
     }
     else if (column==2) {
-      if (entry->item.empty()) {
+      if ((*iter)->item.empty()) {
         return _(L"LABEL_WEIGHT",L"Weight");
       }
       else {
-        return entry->item+L" ("+AmountToString(entry->amount)+L" "+entry->unit+L")";
+        return (*iter)->item+L" ("+AmountToString((*iter)->amount)+L" "+(*iter)->unit+L")";
       }
     }
     else if (column==3) {
-      if (entry->item.empty()) {
-        return AmountToString(entry->amount)+L" "+weightUnit->Get();
+      if ((*iter)->item.empty()) {
+        return AmountToString((*iter)->amount)+L" "+weightUnit->Get();
       }
       else {
-        return ValueToString((((Value)entry->amount)*entry->value)/10)+L" "+valueUnit->Get();
+        return ValueToString((((Value)(*iter)->amount)*(*iter)->value)/10)+L" "+valueUnit->Get();
       }
     }
 
     assert(false);
   }
+};
 
-  bool IsGreater(const Entry* other, size_t column)
+class EntryComparator : public EntryModel::Comparator
+{
+public:
+  bool operator()(const EntryModel::ElementType& a,
+                  const EntryModel::ElementType& b,
+                  size_t column, bool down) const
   {
-    return entry->time>dynamic_cast<const EntriesEntry*>(other)->entry->time;
+    if (down) {
+      return a->time>b->time;
+    }
+    else {
+      return a->time<b->time;
+    }
   }
 };
 
@@ -246,7 +246,7 @@ DataInput::DataInput()
 
    averageDiff(new Lum::Model::String(L"")),
    summary(new Lum::Model::String(L"")),
-   entries(new Lum::Model::ListTable()),
+   entries(new EntryModel(new EntryDataProvider(),new EntryComparator())),
    entrySelection(new Lum::Model::SingleLineSelection()),
 
    trend(new Lum::Model::Int(Trend::none))
@@ -304,13 +304,13 @@ void DataInput::CalcSize()
   ds->AddSpace();
 
   text=Lum::TextValue::Create(averageDiff,Lum::TextValue::left,true,false);
-  text->SetMinWidth(Lum::Base::Size::stdCharWidth,6);
+  text->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
   ds->Add(text);
 
   ds->AddSpace();
 
   text=Lum::TextValue::Create(summary,Lum::TextValue::right,true,false);
-  text->SetMinWidth(Lum::Base::Size::stdCharWidth,9);
+  text->SetMinWidth(Lum::Base::Size::stdCharWidth,8);
   ds->Add(text);
 
   ds->AddSpace(true)
@@ -391,7 +391,7 @@ void DataInput::UpdateEntries()
   entries->Off();
 
   for (std::list<Entry>::iterator iter=day->entries.begin(); iter!=day->entries.end(); ++iter) {
-    entries->Append(new EntriesEntry(entries,&*iter));
+    entries->Append(&*iter);
   }
 
   entries->Sort(1);
@@ -561,7 +561,7 @@ void DataInput::AddWeight()
   e.value=0;
   e.amount=amount;
 
-  entries->Append(new EntriesEntry(entries,data.AddEntry(date->Get(),e)));
+  entries->Append(data.AddEntry(date->Get(),e));
 
   entries->Sort(1);
 
@@ -571,7 +571,7 @@ void DataInput::AddWeight()
 void DataInput::RemoveItem()
 {
   data.DeleteEntry(date->Get(),
-                   dynamic_cast<EntriesEntry*>(entries->GetEntry(entrySelection->GetLine()))->entry);
+                   entries->GetEntry(entrySelection->GetLine()));
   entries->Delete(entrySelection->GetLine());
 
   UpdateSummary();
@@ -579,15 +579,15 @@ void DataInput::RemoveItem()
 
 void DataInput::EditItem()
 {
-  EntriesEntry *entry=(EntriesEntry*)entries->GetEntry(entrySelection->GetLine());
+  Entry *entry=entries->GetEntry(entrySelection->GetLine());
 
-  if (entry->entry->item.empty()) {
+  if (entry->item.empty()) {
     Lum::Model::StringRef value;
     size_t                amount;
 
     timestamp->Push();
-    timestamp->Set(entry->entry->time);
-    value=new Lum::Model::String(AmountToString(entry->entry->amount));
+    timestamp->Set(entry->time);
+    value=new Lum::Model::String(AmountToString(entry->amount));
 
     if (!WeightEdit::EditWeight(this->GetWindow(),
                                 _(L"WEIGHT_EDIT_TITLE",L"My weight is..."),
@@ -612,8 +612,8 @@ void DataInput::EditItem()
       return;
     }
 
-    entry->entry->amount=amount;
-    entry->entry->time=timestamp->Get();
+    entry->amount=amount;
+    entry->time=timestamp->Get();
     entries->RedrawRow(entrySelection->GetLine());
 
     entries->Sort(1);
@@ -626,15 +626,15 @@ void DataInput::EditItem()
     std::wstring          t1,t2;
 
     timestamp->Push();
-    timestamp->Set(entry->entry->time);
-    value=new Lum::Model::String(AmountToString(entry->entry->amount));
+    timestamp->Set(entry->time);
+    value=new Lum::Model::String(AmountToString(entry->amount));
 
     t1=_(L"FOOD_REGISTER_TITLE",L"I have consumed $food...");
-    Lum::Base::L10N::Substitute(t1,L"$food",entry->entry->item);
+    Lum::Base::L10N::Substitute(t1,L"$food",entry->item);
     t2=_(L"FOOD_REGISTER_TEXT",L"Please enter the amount of $food\nyou have consumed!");
-    Lum::Base::L10N::Substitute(t2,L"$food",entry->entry->item);
+    Lum::Base::L10N::Substitute(t2,L"$food",entry->item);
     if (!FoodEdit::EditFood(this->GetWindow(),
-                            t1,t2,timestamp,value,entry->entry->unit)) {
+                            t1,t2,timestamp,value,entry->unit)) {
 
       timestamp->Pop();
       return;
@@ -650,8 +650,8 @@ void DataInput::EditItem()
       return;
     }
 
-    entry->entry->time=timestamp->Get();
-    entry->entry->amount=amount;
+    entry->time=timestamp->Get();
+    entry->amount=amount;
     entries->RedrawRow(entrySelection->GetLine());
 
     entries->Sort(1);
