@@ -25,6 +25,7 @@
 #include <Lum/Array.h>
 #include <Lum/Button.h>
 #include <Lum/DateSelect.h>
+#include <Lum/Label.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
@@ -232,11 +233,15 @@ public:
   FoodFormatProvider(FoodModel* table)
    : table(table),
      goodFoodColor(0.82,1.0,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
-     badFoodColor(1.0,0.82,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
-     goodFoodBackground(new Lum::OS::PlainFill(goodFoodColor)),
-     badFoodBackground(new Lum::OS::PlainFill(badFoodColor))
+     badFoodColor(1.0,0.82,0.82,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor))
   {
-    // no code
+    if (!Lum::OS::display->GetTheme()->IsLightTheme()) {
+      goodFoodColor.Allocate(0.0,0.2,0.0,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor));
+      badFoodColor.Allocate(0.2,0.0,0.0,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor));
+    }
+
+    goodFoodBackground=new Lum::OS::PlainFill(goodFoodColor);
+    badFoodBackground=new Lum::OS::PlainFill(badFoodColor);
   }
 
   Lum::OS::Fill* GetBackground(size_t column, size_t row) const
@@ -296,9 +301,11 @@ void FoodInput::CalcSize()
 
   sb=Lum::VPanel::Create(true,false);
   sb->Add(Lum::HPanel::Create(true,false)
-          ->Add(Lum::Text::Create(L"Search:"))
-          ->AddSpace()
-          ->Add(Lum::String::Create(foodSearch,true,false)->ShowClearButton(true))
+          ->Add(Lum::Label::Create(true,false)
+                ->AddLabel(L"Search:",
+                           Lum::String::Create(foodSearch,true,false)
+                           ->ShowClearButton(true)
+                           ->SetLabel(L"Search")))
           ->AddSpace()
           ->Add(Lum::Button::Create(L"+",
                                     Lum::OS::Theme::imageAdd,
